SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL';

CREATE SCHEMA IF NOT EXISTS `SYMPHONY` DEFAULT CHARACTER SET latin1 ;
USE `SYMPHONY` ;

-- -----------------------------------------------------
-- Table `SYMPHONY`.`residue`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `SYMPHONY`.`residue` ;

CREATE  TABLE IF NOT EXISTS `SYMPHONY`.`residue` (
  `wt` CHAR NOT NULL ,
  `pos` VARCHAR(5) NOT NULL ,
  `exposure` VARCHAR(64) NULL ,
  `rsa_single` FLOAT NULL ,
  `rsa_complex` FLOAT NULL ,
  `sst` VARCHAR(64) NULL ,
  `interface_mol` VARCHAR(64) NULL DEFAULT NULL ,
  PRIMARY KEY (`wt`, `pos`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `SYMPHONY`.`mutation`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `SYMPHONY`.`mutation` ;

CREATE  TABLE IF NOT EXISTS `SYMPHONY`.`mutation` (
  `wt` CHAR NOT NULL ,
  `pos` VARCHAR(5) NOT NULL ,
  `mt` CHAR NOT NULL ,
  `code` VARCHAR(5) NULL ,
  `dataset` VARCHAR(64) NULL DEFAULT NULL ,
  PRIMARY KEY (`wt`, `pos`, `mt`) ,
  INDEX `fk_mutation_residue` (`wt` ASC, `pos` ASC) ,
  CONSTRAINT `fk_mutation_residue`
    FOREIGN KEY (`wt` , `pos` )
    REFERENCES `SYMPHONY`.`residue` (`wt` , `pos` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `SYMPHONY`.`prediction`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `SYMPHONY`.`prediction` ;

CREATE  TABLE IF NOT EXISTS `SYMPHONY`.`prediction` (
  `wt` CHAR NOT NULL ,
  `pos` VARCHAR(5) NOT NULL ,
  `mt` CHAR NOT NULL ,
  `stab_mcsm` FLOAT NULL ,
  `stab_pop` FLOAT NULL ,
  `stab_sdm` FLOAT NULL ,
  `stab_mosst` FLOAT NULL ,
  `stab_combined` FLOAT NULL ,
  `ppi_mcsm` FLOAT NULL ,
  `ppi_beat` FLOAT NULL ,
  `ppi_combined` FLOAT NULL ,
  `binary_risk` VARCHAR(5) NULL ,
  INDEX `fk_prediction_mutation1` (`wt` ASC, `pos` ASC, `mt` ASC) ,
  PRIMARY KEY (`wt`, `pos`, `mt`) ,
  CONSTRAINT `fk_prediction_mutation1`
    FOREIGN KEY (`wt` , `pos` , `mt` )
    REFERENCES `SYMPHONY`.`mutation` (`wt` , `pos` , `mt` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `SYMPHONY`.`external`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `SYMPHONY`.`external` ;

CREATE  TABLE IF NOT EXISTS `SYMPHONY`.`external` (
  `wt` CHAR NOT NULL ,
  `pos` VARCHAR(5) NOT NULL ,
  `mt` CHAR NOT NULL ,
  `cosmic_id` VARCHAR(64) NULL ,
  INDEX `fk_external_mutation1` (`wt` ASC, `pos` ASC, `mt` ASC) ,
  PRIMARY KEY (`wt`, `pos`, `mt`) ,
  CONSTRAINT `fk_external_mutation1`
    FOREIGN KEY (`wt` , `pos` , `mt` )
    REFERENCES `SYMPHONY`.`mutation` (`wt` , `pos` , `mt` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `SYMPHONY`.`experimental`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `SYMPHONY`.`experimental` ;

CREATE  TABLE IF NOT EXISTS `SYMPHONY`.`experimental` (
  `wt` CHAR NOT NULL ,
  `pos` VARCHAR(5) NOT NULL ,
  `mt` CHAR NOT NULL ,
  `hif_reg` VARCHAR(128) NULL DEFAULT NULL ,
  `is_germline` VARCHAR(5) NULL DEFAULT NULL ,
  `is_non_pathogenic_dbsnp` VARCHAR(5) NULL DEFAULT NULL ,
  `is_vhl_disease` VARCHAR(5) NULL DEFAULT NULL ,
  `num_vhl_disease_kindreds` INT NULL DEFAULT NULL ,
  `is_vhl_disease_with_ccrcc` VARCHAR(5) NULL DEFAULT NULL ,
  `vhl_disease_type` VARCHAR(5) NULL DEFAULT NULL ,
  `is_polycythaemia` VARCHAR(5) NULL DEFAULT 'NO' ,
  `is_phaeo` VARCHAR(5) NULL DEFAULT NULL ,
  `is_somatic_cosmic` VARCHAR(5) NULL DEFAULT NULL ,
  `is_somatic_ccrcc` VARCHAR(5) NULL DEFAULT NULL ,
  `num_somatic_ccrcc` INT NULL DEFAULT NULL ,
  `additional_somatic` VARCHAR(64) NULL DEFAULT NULL ,
  INDEX `fk_experimental_mutation1` (`wt` ASC, `pos` ASC, `mt` ASC) ,
  PRIMARY KEY (`wt`, `pos`, `mt`) ,
  CONSTRAINT `fk_experimental_mutation1`
    FOREIGN KEY (`wt` , `pos` , `mt` )
    REFERENCES `SYMPHONY`.`mutation` (`wt` , `pos` , `mt` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;



SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;
